Class: GrowsurfRuby::Models::Account

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/growsurf_ruby/models/account.rb,
sig/growsurf_ruby/models/account.rbs

Overview

See Also:

  • GrowsurfRuby::Resources::Account#retrieve

Defined Under Namespace

Modules: VerificationStatus

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(email:, id:, verification_status:, company: nil, created_at: nil, first_name: nil, last_name: nil, verification_requested_at: nil) ⇒ Object

Some parameter documentations has been truncated, see GrowsurfRuby::Models::Account for more details.

Parameters:

  • email (String)
  • id (String)

    The account's unique identifier.

  • verification_status (Symbol, GrowsurfRuby::Models::Account::VerificationStatus)

    GrowSurf-team verification state. VERIFIED is required before a program can send

  • company (String, nil) (defaults to: nil)
  • created_at (Integer, nil) (defaults to: nil)

    When the account was created, as a Unix timestamp in milliseconds.

  • first_name (String, nil) (defaults to: nil)
  • last_name (String, nil) (defaults to: nil)
  • verification_requested_at (Integer, nil) (defaults to: nil)

    When team verification was last requested, as a Unix timestamp in milliseconds.



# File 'lib/growsurf_ruby/models/account.rb', line 54

Instance Attribute Details

#companyString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


30
# File 'lib/growsurf_ruby/models/account.rb', line 30

optional :company, String, nil?: true

#created_atInteger?

When the account was created, as a Unix timestamp in milliseconds.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


36
# File 'lib/growsurf_ruby/models/account.rb', line 36

optional :created_at, Integer, api_name: :createdAt, nil?: true

#emailString

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/growsurf_ruby/models/account.rb', line 10

required :email, String

#first_nameString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


41
# File 'lib/growsurf_ruby/models/account.rb', line 41

optional :first_name, String, api_name: :firstName, nil?: true

#idString

The account's unique identifier.

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/growsurf_ruby/models/account.rb', line 16

required :id, String

#last_nameString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


46
# File 'lib/growsurf_ruby/models/account.rb', line 46

optional :last_name, String, api_name: :lastName, nil?: true

#verification_requested_atInteger?

When team verification was last requested, as a Unix timestamp in milliseconds.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


52
# File 'lib/growsurf_ruby/models/account.rb', line 52

optional :verification_requested_at, Integer, api_name: :verificationRequestedAt, nil?: true

#verification_statusSymbol, GrowsurfRuby::Models::Account::VerificationStatus

GrowSurf-team verification state. VERIFIED is required before a program can send participant emails.

Parameters:

  • value (GrowsurfRuby::Models::Account::verification_status)

Returns:



23
24
25
# File 'lib/growsurf_ruby/models/account.rb', line 23

required :verification_status,
enum: -> { GrowsurfRuby::Account::VerificationStatus },
api_name: :verificationStatus

Instance Method Details

#to_hash{

Returns:

  • ({)


43
# File 'sig/growsurf_ruby/models/account.rbs', line 43

def to_hash: -> {