Class: GrowsurfRuby::Models::AccountCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/growsurf_ruby/models/account_create_response.rb,
sig/growsurf_ruby/models/account_create_response.rbs

Overview

See Also:

  • GrowsurfRuby::Resources::Account#create

Defined Under Namespace

Modules: VerificationStatus

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(api_key:, email:, id:, verification_status:) ⇒ Object

Some parameter documentations has been truncated, see GrowsurfRuby::Models::AccountCreateResponse for more details.

Parameters:

  • api_key (String)

    An API key for the new account. Use it as the Bearer token on subsequent

  • email (String)
  • id (String)

    The new account's unique identifier.

  • verification_status (Symbol, GrowsurfRuby::Models::AccountCreateResponse::VerificationStatus)

    GrowSurf account verification state. VERIFIED is required before a program can



# File 'lib/growsurf_ruby/models/account_create_response.rb', line 36

Instance Attribute Details

#api_keyString

An API key for the new account. Use it as the Bearer token on subsequent requests. Locked (403 EMAIL_NOT_VERIFIED_ERROR) until the account's email is verified, and rotated when the account owner first signs in to the GrowSurf dashboard.

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/growsurf_ruby/models/account_create_response.rb', line 14

required :api_key, String, api_name: :apiKey

#emailString

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/growsurf_ruby/models/account_create_response.rb', line 19

required :email, String

#idString

The new account's unique identifier.

Parameters:

  • value (String)

Returns:

  • (String)


25
# File 'lib/growsurf_ruby/models/account_create_response.rb', line 25

required :id, String

#verification_statusSymbol, GrowsurfRuby::Models::AccountCreateResponse::VerificationStatus

GrowSurf account verification state. VERIFIED is required before a program can send participant emails.

Parameters:

  • value (GrowsurfRuby::Models::AccountCreateResponse::verification_status)

Returns:



32
33
34
# File 'lib/growsurf_ruby/models/account_create_response.rb', line 32

required :verification_status,
enum: -> { GrowsurfRuby::Models::AccountCreateResponse::VerificationStatus },
api_name: :verificationStatus

Instance Method Details

#to_hash{

Returns:

  • ({)


27
# File 'sig/growsurf_ruby/models/account_create_response.rbs', line 27

def to_hash: -> {