Class: GrowsurfRuby::Models::Campaign::CampaignParticipant
Overview
Defined Under Namespace
Classes: PayoutSettings, Referrer
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
-
#initialize(id:, email:, monthly_rank:, monthly_referral_count:, rank:, referral_count:, rewards:, share_url: nil, affiliate_enrollment_source: nil, affiliate_status: nil, all_matching_fraudsters: nil, created_at: nil, fingerprint: nil, first_name: nil, fraud_reason_code: nil, fraud_risk_level: nil, impression_count: nil, invite_count: nil, ip_address: nil, is_affiliate: nil, is_new: nil, is_winner: nil, last_name: nil, metadata: nil, mobile_instance_id: nil, monthly_referrals: nil, notes: nil, payout_settings: nil, paypal_email_address: nil, prev_monthly_rank: nil, prev_monthly_referral_count: nil, referrals: nil, referral_source: nil, referral_status: nil, referred_by: nil, referrer: nil, share_count: nil, unique_impression_count: nil, unread_commissions_count: nil, unread_payouts_count: nil, unsubscribed: nil, vanity_keys: nil) ⇒ Object
constructor
-
#to_hash ⇒ {
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, email:, monthly_rank:, monthly_referral_count:, rank:, referral_count:, rewards:, share_url: nil, affiliate_enrollment_source: nil, affiliate_status: nil, all_matching_fraudsters: nil, created_at: nil, fingerprint: nil, first_name: nil, fraud_reason_code: nil, fraud_risk_level: nil, impression_count: nil, invite_count: nil, ip_address: nil, is_affiliate: nil, is_new: nil, is_winner: nil, last_name: nil, metadata: nil, mobile_instance_id: nil, monthly_referrals: nil, notes: nil, payout_settings: nil, paypal_email_address: nil, prev_monthly_rank: nil, prev_monthly_referral_count: nil, referrals: nil, referral_source: nil, referral_status: nil, referred_by: nil, referrer: nil, share_count: nil, unique_impression_count: nil, unread_commissions_count: nil, unread_payouts_count: nil, unsubscribed: nil, vanity_keys: nil) ⇒ Object
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 252
|
Instance Attribute Details
#affiliate_enrollment_source ⇒ String?
Affiliate programs only. How the affiliate enrolled (OPEN_ENROLLMENT,
APPLICATION, PARTICIPANT_AUTH, INVITE, REST_API, CSV, or DASHBOARD).
null when not recorded.
56
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 56
optional :affiliate_enrollment_source, String, api_name: :affiliateEnrollmentSource, nil?: true
|
#affiliate_status ⇒ String?
Affiliate programs only. The enrolled affiliate's status (APPROVED,
SUSPENDED, or BANNED). null for participants who are not affiliates.
63
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 63
optional :affiliate_status, String, api_name: :affiliateStatus, nil?: true
|
#all_matching_fraudsters ⇒ Array<Hash{Symbol=>Object}>?
68
69
70
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 68
optional :all_matching_fraudsters,
GrowsurfRuby::Internal::Type::ArrayOf[GrowsurfRuby::Internal::Type::HashOf[GrowsurfRuby::Internal::Type::Unknown]],
api_name: :allMatchingFraudsters
|
#created_at ⇒ Integer?
75
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 75
optional :created_at, Integer, api_name: :createdAt
|
#email ⇒ String
16
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 16
required :email, String
|
#fingerprint ⇒ String?
80
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 80
optional :fingerprint, String, nil?: true
|
#first_name ⇒ String?
85
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 85
optional :first_name, String, api_name: :firstName, nil?: true
|
#fraud_reason_code ⇒ String?
90
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 90
optional :fraud_reason_code, String, api_name: :fraudReasonCode
|
#fraud_risk_level ⇒ Symbol, ...
95
96
97
98
99
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 95
optional :fraud_risk_level,
enum: -> {
GrowsurfRuby::Campaign::FraudRiskLevel
},
api_name: :fraudRiskLevel
|
#id ⇒ String
11
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 11
required :id, String
|
#impression_count ⇒ Integer?
104
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 104
optional :impression_count, Integer, api_name: :impressionCount
|
#invite_count ⇒ Integer?
109
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 109
optional :invite_count, Integer, api_name: :inviteCount
|
#ip_address ⇒ String?
114
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 114
optional :ip_address, String, api_name: :ipAddress, nil?: true
|
#is_affiliate ⇒ Boolean?
Affiliate programs only. Whether this participant is an enrolled affiliate. A
referred customer who has not joined the program is false.
121
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 121
optional :is_affiliate, GrowsurfRuby::Internal::Type::Boolean, api_name: :isAffiliate
|
#is_new ⇒ Boolean?
126
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 126
optional :is_new, GrowsurfRuby::Internal::Type::Boolean, api_name: :isNew
|
#is_winner ⇒ Boolean?
131
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 131
optional :is_winner, GrowsurfRuby::Internal::Type::Boolean, api_name: :isWinner
|
#last_name ⇒ String?
136
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 136
optional :last_name, String, api_name: :lastName, nil?: true
|
Shallow custom metadata object.
142
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 142
optional :metadata, GrowsurfRuby::Internal::Type::HashOf[GrowsurfRuby::Internal::Type::Unknown]
|
#mobile_instance_id ⇒ String?
App-install scoped mobile identifier used for anti-fraud matching when provided
by native mobile apps. The official mobile SDKs generate this as a lowercase
UUID. Not stored when strict GDPR/CCPA mode is enabled.
150
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 150
optional :mobile_instance_id, String, api_name: :mobileInstanceId, nil?: true
|
#monthly_rank ⇒ Integer
21
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 21
required :monthly_rank, Integer, api_name: :monthlyRank
|
#monthly_referral_count ⇒ Integer
26
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 26
required :monthly_referral_count, Integer, api_name: :monthlyReferralCount
|
#monthly_referrals ⇒ Array<String>?
155
156
157
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 155
optional :monthly_referrals,
GrowsurfRuby::Internal::Type::ArrayOf[String],
api_name: :monthlyReferrals
|
#notes ⇒ String?
162
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 162
optional :notes, String, nil?: true
|
Payout-related actions the participant must complete before a payout can be
released (e.g. configuring a payout destination or submitting a W-9/W-8 tax form).
Always present; the requiredActions array is empty when no action is required.
170
171
172
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 170
optional :payout_settings,
-> { GrowsurfRuby::Campaign::CampaignParticipant::PayoutSettings },
api_name: :payoutSettings
|
#paypal_email_address ⇒ String?
177
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 177
optional :paypal_email_address, String, api_name: :paypalEmailAddress
|
#prev_monthly_rank ⇒ Integer?
182
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 182
optional :prev_monthly_rank, Integer, api_name: :prevMonthlyRank
|
#prev_monthly_referral_count ⇒ Integer?
187
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 187
optional :prev_monthly_referral_count, Integer, api_name: :prevMonthlyReferralCount
|
#rank ⇒ Integer
31
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 31
required :rank, Integer
|
#referral_count ⇒ Integer
36
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 36
required :referral_count, Integer, api_name: :referralCount
|
#referral_source ⇒ Symbol, ...
197
198
199
200
201
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 197
optional :referral_source,
enum: -> {
GrowsurfRuby::Campaign::ReferralSource
},
api_name: :referralSource
|
#referral_status ⇒ Symbol, ...
206
207
208
209
210
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 206
optional :referral_status,
enum: -> {
GrowsurfRuby::Campaign::ReferralStatus
},
api_name: :referralStatus
|
#referrals ⇒ Array<String>?
192
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 192
optional :referrals, GrowsurfRuby::Internal::Type::ArrayOf[String]
|
#referred_by ⇒ String?
215
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 215
optional :referred_by, String, api_name: :referredBy
|
220
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 220
optional :referrer, -> { GrowsurfRuby::Campaign::CampaignParticipant::Referrer }, nil?: true
|
41
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 41
required :rewards, -> { GrowsurfRuby::Internal::Type::ArrayOf[GrowsurfRuby::Campaign::ParticipantReward] }
|
#share_count ⇒ Hash{Symbol=>Integer}?
225
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 225
optional :share_count, GrowsurfRuby::Internal::Type::HashOf[Integer], api_name: :shareCount
|
#share_url ⇒ String?
The unique share URL of the participant. Omitted for affiliate program
participants who are not approved affiliates.
48
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 48
optional :share_url, String, api_name: :shareUrl
|
#unique_impression_count ⇒ Integer?
230
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 230
optional :unique_impression_count, Integer, api_name: :uniqueImpressionCount
|
#unread_commissions_count ⇒ Integer?
235
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 235
optional :unread_commissions_count, Integer, api_name: :unreadCommissionsCount
|
#unread_payouts_count ⇒ Integer?
240
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 240
optional :unread_payouts_count, Integer, api_name: :unreadPayoutsCount
|
#unsubscribed ⇒ Boolean?
245
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 245
optional :unsubscribed, GrowsurfRuby::Internal::Type::Boolean
|
#vanity_keys ⇒ Array<String>?
250
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 250
optional :vanity_keys, GrowsurfRuby::Internal::Type::ArrayOf[String], api_name: :vanityKeys
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 368
|
Instance Method Details
#to_hash ⇒ {
242
|
# File 'sig/growsurf_ruby/models/campaign/participant.rbs', line 242
def to_hash: -> {
|