Class: GrowsurfRuby::Models::Campaign::CampaignParticipant::PayoutSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- GrowsurfRuby::Models::Campaign::CampaignParticipant::PayoutSettings
- Defined in:
- lib/growsurf_ruby/models/campaign/participant.rb,
sig/growsurf_ruby/models/campaign/participant.rbs
Overview
Defined Under Namespace
Modules: RequiredAction
Instance Attribute Summary collapse
-
#required_actions ⇒ Array<Symbol, GrowsurfRuby::Models::Campaign::CampaignParticipant::PayoutSettings::RequiredAction>?
Actions the participant must complete before payouts can be sent.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
299 |
# File 'sig/growsurf_ruby/models/campaign/participant.rbs', line 299
def initialize: (
|
Instance Attribute Details
#required_actions ⇒ Array<Symbol, GrowsurfRuby::Models::Campaign::CampaignParticipant::PayoutSettings::RequiredAction>?
Actions the participant must complete before payouts can be sent.
347 348 349 350 351 352 353 |
# File 'lib/growsurf_ruby/models/campaign/participant.rb', line 347 optional :required_actions, -> { GrowsurfRuby::Internal::Type::ArrayOf[ enum: GrowsurfRuby::Campaign::CampaignParticipant::PayoutSettings::RequiredAction ] }, api_name: :requiredActions |
Instance Method Details
#to_hash ⇒ {
303 |
# File 'sig/growsurf_ruby/models/campaign/participant.rbs', line 303
def to_hash: -> {
|