Class: GrowsurfRuby::Models::Campaign::ParticipantActivityLogsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- GrowsurfRuby::Models::Campaign::ParticipantActivityLogsResponse
- Defined in:
- lib/growsurf_ruby/models/campaign/participant_activity_logs_response.rb,
sig/growsurf_ruby/models/campaign/participant_activity_logs_response.rbs
Overview
Defined Under Namespace
Classes: ActivityLog
Instance Attribute Summary collapse
- #activity_logs ⇒ Array<GrowsurfRuby::Models::Campaign::ParticipantActivityLogsResponse::ActivityLog>
- #limit ⇒ Integer
-
#offset ⇒ Integer?
The offset for the next page, or null when there are no more logs.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
18 |
# File 'sig/growsurf_ruby/models/campaign/participant_activity_logs_response.rbs', line 18
def initialize: (
|
Instance Attribute Details
#activity_logs ⇒ Array<GrowsurfRuby::Models::Campaign::ParticipantActivityLogsResponse::ActivityLog>
11 12 13 14 15 16 17 |
# File 'lib/growsurf_ruby/models/campaign/participant_activity_logs_response.rb', line 11 required :activity_logs, -> { GrowsurfRuby::Internal::Type::ArrayOf[ GrowsurfRuby::Campaign::ParticipantActivityLogsResponse::ActivityLog ] }, api_name: :activityLogs |
#limit ⇒ Integer
22 |
# File 'lib/growsurf_ruby/models/campaign/participant_activity_logs_response.rb', line 22 required :limit, Integer |
#offset ⇒ Integer?
The offset for the next page, or null when there are no more logs.
28 |
# File 'lib/growsurf_ruby/models/campaign/participant_activity_logs_response.rb', line 28 optional :offset, Integer, nil?: true |
Instance Method Details
#to_hash ⇒ {
24 |
# File 'sig/growsurf_ruby/models/campaign/participant_activity_logs_response.rbs', line 24
def to_hash: -> {
|