Class: GrowsurfRuby::Models::Campaign::ParticipantAnalyticsResponse::Analytics

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/growsurf_ruby/models/campaign/participant_analytics_response.rb,
sig/growsurf_ruby/models/campaign/participant_analytics_response.rbs

Overview

See Also:

  • GrowsurfRuby::Models::Campaign::ParticipantAnalyticsResponse#analytics

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



123
# File 'sig/growsurf_ruby/models/campaign/participant_analytics_response.rbs', line 123

def initialize: (

Instance Attribute Details

#currency_isoString?

Parameters:

  • (String)

Returns:

  • (String, nil)


75
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 75

optional :currency_iso, String, api_name: :currencyISO

#expired_referralsInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


80
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 80

optional :expired_referrals, Integer, api_name: :expiredReferrals

#impressionsInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


85
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 85

optional :impressions, Integer

#invites_sentInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


90
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 90

optional :invites_sent, Integer, api_name: :invitesSent

#leadsInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


95
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 95

optional :leads, Integer

#monthly_referralsInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


100
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 100

optional :monthly_referrals, Integer, api_name: :monthlyReferrals

#referral_revenueInteger?

Affiliate only. Revenue attributed to this participant's referrals, in minor currency units.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


115
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 115

optional :referral_revenue, Integer, api_name: :referralRevenue

#referralsInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


120
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 120

optional :referrals, Integer

#reward_statusGrowsurfRuby::Models::CampaignRetrieveAnalyticsResponse::StatusCounts::RewardStatus?

This participant's reward counts grouped by review and fulfillment status.



106
107
108
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 106

optional :reward_status,
-> { GrowsurfRuby::Models::CampaignRetrieveAnalyticsResponse::StatusCounts::RewardStatus },
api_name: :rewardStatus

#total_commissionsInteger?

Affiliate only. Total commissions earned, in minor currency units.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


126
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 126

optional :total_commissions, Integer, api_name: :totalCommissions

#total_paid_outInteger?

Affiliate only. Total paid out, in minor currency units.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


132
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 132

optional :total_paid_out, Integer, api_name: :totalPaidOut

#unique_impressionsInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


137
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 137

optional :unique_impressions, Integer, api_name: :uniqueImpressions

#upcoming_payoutInteger?

Affiliate only. Approved commissions ready to pay, in minor currency units.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


143
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 143

optional :upcoming_payout, Integer, api_name: :upcomingPayout

Instance Method Details

#to_hash{

Returns:

  • ({)


139
# File 'sig/growsurf_ruby/models/campaign/participant_analytics_response.rbs', line 139

def to_hash: -> {