Class: GrowsurfRuby::Models::Campaign::ParticipantAnalyticsResponse::Series
- Inherits:
-
Internal::Type::BaseModel
show all
- Defined in:
- lib/growsurf_ruby/models/campaign/participant_analytics_response.rb,
sig/growsurf_ruby/models/campaign/participant_analytics_response.rbs
Instance Attribute Summary collapse
Instance Method Summary
collapse
-
#initialize(android_native_shares: nil, bluesky_shares: nil, copy_ref_link_shares: nil, email_shares: nil, facebook_shares: nil, impressions: nil, invites: nil, ios_native_shares: nil, linked_in_shares: nil, messenger_shares: nil, participants: nil, period_start: nil, pinterest_shares: nil, qrcode_shares: nil, reddit_shares: nil, referral_credit_expireds: nil, referral_credit_pendings: nil, referrals: nil, sms_shares: nil, telegram_shares: nil, threads_shares: nil, total_commission_count: nil, total_commissions: nil, total_revenue: nil, tumblr_shares: nil, twitter_shares: nil, unique_commission_referrals: nil, unique_impressions: nil, wechat_shares: nil, whats_app_shares: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Series for more details.
-
#to_hash ⇒ {
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(android_native_shares: nil, bluesky_shares: nil, copy_ref_link_shares: nil, email_shares: nil, facebook_shares: nil, impressions: nil, invites: nil, ios_native_shares: nil, linked_in_shares: nil, messenger_shares: nil, participants: nil, period_start: nil, pinterest_shares: nil, qrcode_shares: nil, reddit_shares: nil, referral_credit_expireds: nil, referral_credit_pendings: nil, referrals: nil, sms_shares: nil, telegram_shares: nil, threads_shares: nil, total_commission_count: nil, total_commissions: nil, total_revenue: nil, tumblr_shares: nil, twitter_shares: nil, unique_commission_referrals: nil, unique_impressions: nil, wechat_shares: nil, whats_app_shares: nil) ⇒ Object
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 364
|
Instance Attribute Details
#android_native_shares ⇒ Integer?
207
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 207
optional :android_native_shares, Integer, api_name: :androidNativeShares
|
#bluesky_shares ⇒ Integer?
212
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 212
optional :bluesky_shares, Integer, api_name: :blueskyShares
|
#copy_ref_link_shares ⇒ Integer?
217
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 217
optional :copy_ref_link_shares, Integer, api_name: :copyRefLinkShares
|
#email_shares ⇒ Integer?
222
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 222
optional :email_shares, Integer, api_name: :emailShares
|
#facebook_shares ⇒ Integer?
230
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 230
optional :facebook_shares, Integer, api_name: :facebookShares
|
#impressions ⇒ Integer?
235
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 235
optional :impressions, Integer
|
#invites ⇒ Integer?
240
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 240
optional :invites, Integer
|
#ios_native_shares ⇒ Integer?
245
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 245
optional :ios_native_shares, Integer, api_name: :iosNativeShares
|
#linked_in_shares ⇒ Integer?
250
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 250
optional :linked_in_shares, Integer, api_name: :linkedInShares
|
#messenger_shares ⇒ Integer?
255
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 255
optional :messenger_shares, Integer, api_name: :messengerShares
|
#participants ⇒ Integer?
260
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 260
optional :participants, Integer
|
#period_start ⇒ Integer?
Start of the period, as a Unix timestamp in milliseconds (UTC).
266
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 266
optional :period_start, Integer, api_name: :periodStart
|
#pinterest_shares ⇒ Integer?
271
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 271
optional :pinterest_shares, Integer, api_name: :pinterestShares
|
#qrcode_shares ⇒ Integer?
276
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 276
optional :qrcode_shares, Integer, api_name: :qrcodeShares
|
#reddit_shares ⇒ Integer?
281
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 281
optional :reddit_shares, Integer, api_name: :redditShares
|
#referral_credit_expireds ⇒ Integer?
286
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 286
optional :referral_credit_expireds, Integer, api_name: :referralCreditExpireds
|
#referral_credit_pendings ⇒ Integer?
291
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 291
optional :referral_credit_pendings, Integer, api_name: :referralCreditPendings
|
#referrals ⇒ Integer?
296
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 296
optional :referrals, Integer
|
#sms_shares ⇒ Integer?
301
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 301
optional :sms_shares, Integer, api_name: :smsShares
|
#telegram_shares ⇒ Integer?
306
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 306
optional :telegram_shares, Integer, api_name: :telegramShares
|
#threads_shares ⇒ Integer?
311
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 311
optional :threads_shares, Integer, api_name: :threadsShares
|
#total_commission_count ⇒ Integer?
Affiliate programs only. Number of commission records.
317
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 317
optional :total_commission_count, Integer, api_name: :totalCommissionCount
|
#total_commissions ⇒ Integer?
Affiliate programs only. Commissions in the smallest unit of the program
currency.
324
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 324
optional :total_commissions, Integer, api_name: :totalCommissions
|
#total_revenue ⇒ Integer?
Affiliate programs only. Revenue in the smallest unit of the program currency.
330
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 330
optional :total_revenue, Integer, api_name: :totalRevenue
|
#tumblr_shares ⇒ Integer?
335
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 335
optional :tumblr_shares, Integer, api_name: :tumblrShares
|
340
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 340
optional :twitter_shares, Integer, api_name: :twitterShares
|
#unique_commission_referrals ⇒ Integer?
Affiliate programs only. Number of unique referred participants represented by
commissions in the requested timeframe.
347
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 347
optional :unique_commission_referrals, Integer, api_name: :uniqueCommissionReferrals
|
#unique_impressions ⇒ Integer?
352
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 352
optional :unique_impressions, Integer, api_name: :uniqueImpressions
|
#wechat_shares ⇒ Integer?
357
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 357
optional :wechat_shares, Integer, api_name: :wechatShares
|
#whats_app_shares ⇒ Integer?
362
|
# File 'lib/growsurf_ruby/models/campaign/participant_analytics_response.rb', line 362
optional :whats_app_shares, Integer, api_name: :whatsAppShares
|
Instance Method Details
#to_hash ⇒ {
371
|
# File 'sig/growsurf_ruby/models/campaign/participant_analytics_response.rbs', line 371
def to_hash: -> {
|