Class: GrowsurfRuby::Models::Campaign::ParticipantBulkDeleteResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- GrowsurfRuby::Models::Campaign::ParticipantBulkDeleteResponse
- Defined in:
- lib/growsurf_ruby/models/campaign/participant_bulk_delete_response.rb,
sig/growsurf_ruby/models/campaign/participant_bulk_delete_response.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#results ⇒ Array<GrowsurfRuby::Models::Campaign::ParticipantBulkDeleteResponse::Result>
One entry per submitted identifier, in the same order as the request.
- #summary ⇒ GrowsurfRuby::Models::Campaign::ParticipantBulkDeleteResponse::Summary
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
15 |
# File 'sig/growsurf_ruby/models/campaign/participant_bulk_delete_response.rbs', line 15
def initialize: (
|
Instance Attribute Details
#results ⇒ Array<GrowsurfRuby::Models::Campaign::ParticipantBulkDeleteResponse::Result>
One entry per submitted identifier, in the same order as the request.
12 13 14 15 16 17 |
# File 'lib/growsurf_ruby/models/campaign/participant_bulk_delete_response.rb', line 12 required :results, -> { GrowsurfRuby::Internal::Type::ArrayOf[ GrowsurfRuby::Campaign::ParticipantBulkDeleteResponse::Result ] } |
#summary ⇒ GrowsurfRuby::Models::Campaign::ParticipantBulkDeleteResponse::Summary
22 |
# File 'lib/growsurf_ruby/models/campaign/participant_bulk_delete_response.rb', line 22 required :summary, -> { GrowsurfRuby::Campaign::ParticipantBulkDeleteResponse::Summary } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/growsurf_ruby/models/campaign/participant_bulk_delete_response.rb', line 101
|
Instance Method Details
#to_hash ⇒ {
20 |
# File 'sig/growsurf_ruby/models/campaign/participant_bulk_delete_response.rbs', line 20
def to_hash: -> {
|