Class: GrowsurfRuby::Models::Campaign::ParticipantBulkDeleteResponse::Summary

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/growsurf_ruby/models/campaign/participant_bulk_delete_response.rb,
sig/growsurf_ruby/models/campaign/participant_bulk_delete_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(deleted_count:, duplicate_count:, error_count:, not_found_count:, total:) ⇒ Object

Parameters:

  • deleted_count (Integer)

    Entries that resolved to a participant and were deleted.

  • duplicate_count (Integer)

    Entries that resolved to the same participant as an earlier entry.

  • error_count (Integer)

    Entries that failed to look up or delete.

  • not_found_count (Integer)

    Entries that did not match any participant.

  • total (Integer)

    Number of entries submitted in this request.



# File 'lib/growsurf_ruby/models/campaign/participant_bulk_delete_response.rb', line 137

Instance Attribute Details

#deleted_countInteger

Entries that resolved to a participant and were deleted.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


111
# File 'lib/growsurf_ruby/models/campaign/participant_bulk_delete_response.rb', line 111

required :deleted_count, Integer, api_name: :deletedCount

#duplicate_countInteger

Entries that resolved to the same participant as an earlier entry.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


117
# File 'lib/growsurf_ruby/models/campaign/participant_bulk_delete_response.rb', line 117

required :duplicate_count, Integer, api_name: :duplicateCount

#error_countInteger

Entries that failed to look up or delete.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


123
# File 'lib/growsurf_ruby/models/campaign/participant_bulk_delete_response.rb', line 123

required :error_count, Integer, api_name: :errorCount

#not_found_countInteger

Entries that did not match any participant.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


129
# File 'lib/growsurf_ruby/models/campaign/participant_bulk_delete_response.rb', line 129

required :not_found_count, Integer, api_name: :notFoundCount

#totalInteger

Number of entries submitted in this request.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


135
# File 'lib/growsurf_ruby/models/campaign/participant_bulk_delete_response.rb', line 135

required :total, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


114
# File 'sig/growsurf_ruby/models/campaign/participant_bulk_delete_response.rbs', line 114

def to_hash: -> {