Class: GrowsurfRuby::Models::Campaign::ParticipantEmailParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/growsurf_ruby/models/campaign/participant_email_params.rb,
sig/growsurf_ruby/models/campaign/participant_email_params.rbs

Overview

See Also:

  • GrowsurfRuby::Resources::Campaign::Participant#email

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::GrowsurfRuby

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, participant_id_or_email:, body: nil, email_type: nil, preheader: nil, subject: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see GrowsurfRuby::Models::Campaign::ParticipantEmailParams for more details.

Parameters:

  • id (String)
  • participant_id_or_email (String)
  • body (String) (defaults to: nil)

    HTML body for a free-form email. You can personalize it with dynamic text, inserting {{...}} tokens like {{firstName}} or {{shareUrl}}. See Guide to using dynamic text in GrowSurf emails.

  • email_type (String) (defaults to: nil)

    The program email template to send (template mode). Send the camelCase key; it m

  • preheader (String) (defaults to: nil)

    Optional preheader text for a free-form email.

  • subject (String) (defaults to: nil)

    Subject line for a free-form email. Supports dynamic text ({{...}} tokens), the same as the body.

  • request_options (GrowsurfRuby::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/growsurf_ruby/models/campaign/participant_email_params.rb', line 56

Instance Attribute Details

#bodyString?

HTML body for a free-form email. You can personalize it with dynamic text, inserting {{...}} tokens like {{firstName}} or {{shareUrl}}. See Guide to using dynamic text in GrowSurf emails.

Parameters:

  • (String)

Returns:

  • (String, nil)


27
# File 'lib/growsurf_ruby/models/campaign/participant_email_params.rb', line 27

optional :body, String

#email_typeString?

The program email template to send (template mode). Send the camelCase key. The valid types depend on the program type; isEnabled only controls automatic sends. Referral programs: welcomeNonReferred, referralLinkViewedFirstTime, referralLinkUsed, referredSignup, welcomeReferred, goalAchieved, campaignEndedWinners, campaignEndedNonWinners, progressUpdateMonthly. Affiliate programs: welcomeNonReferred, referralLinkViewedFirstTime, referredSignup, commissionGenerated, commissionAdjusted, payoutPending, payoutSentSuccess, progressUpdateMonthly. System/transactional types (login link, PayPal confirmation, tax) and the invite email cannot be sent.

Parameters:

  • (String)

Returns:

  • (String, nil)


41
# File 'lib/growsurf_ruby/models/campaign/participant_email_params.rb', line 41

optional :email_type, String, api_name: :emailType

#idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/growsurf_ruby/models/campaign/participant_email_params.rb', line 14

required :id, String

#participant_id_or_emailString

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/growsurf_ruby/models/campaign/participant_email_params.rb', line 19

required :participant_id_or_email, String

#preheaderString?

Optional preheader text for a free-form email.

Parameters:

  • (String)

Returns:

  • (String, nil)


47
# File 'lib/growsurf_ruby/models/campaign/participant_email_params.rb', line 47

optional :preheader, String

#subjectString?

Subject line for a free-form email. Supports dynamic text ({{...}} tokens), the same as the body.

Parameters:

  • (String)

Returns:

  • (String, nil)


54
# File 'lib/growsurf_ruby/models/campaign/participant_email_params.rb', line 54

optional :subject, String

Instance Method Details

#to_hash{

Returns:

  • ({)


49
# File 'sig/growsurf_ruby/models/campaign/participant_email_params.rbs', line 49

def to_hash: -> {