Class: GrowsurfRuby::Models::Campaign::ParticipantListPayoutsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- GrowsurfRuby::Models::Campaign::ParticipantListPayoutsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/growsurf_ruby/models/campaign/participant_list_payouts_params.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
- #id ⇒ String
-
#limit ⇒ Integer?
Number of results to return.
-
#next_id ⇒ String?
ID to start the next paged result set with.
- #participant_id_or_email ⇒ String
-
#status ⇒ Symbol, ...
Participant payout status.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, participant_id_or_email:, limit: nil, next_id: nil, status: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/growsurf_ruby/models/campaign/participant_list_payouts_params.rb', line 39
|
Instance Attribute Details
#id ⇒ String
14 |
# File 'lib/growsurf_ruby/models/campaign/participant_list_payouts_params.rb', line 14 required :id, String |
#limit ⇒ Integer?
Number of results to return. Maximum 100.
25 |
# File 'lib/growsurf_ruby/models/campaign/participant_list_payouts_params.rb', line 25 optional :limit, Integer |
#next_id ⇒ String?
ID to start the next paged result set with.
31 |
# File 'lib/growsurf_ruby/models/campaign/participant_list_payouts_params.rb', line 31 optional :next_id, String |
#participant_id_or_email ⇒ String
19 |
# File 'lib/growsurf_ruby/models/campaign/participant_list_payouts_params.rb', line 19 required :participant_id_or_email, String |
#status ⇒ Symbol, ...
Participant payout status.
37 |
# File 'lib/growsurf_ruby/models/campaign/participant_list_payouts_params.rb', line 37 optional :status, enum: -> { GrowsurfRuby::Campaign::ParticipantListPayoutsParams::Status } |