Class: GrowsurfRuby::Models::Campaign::ParticipantListReferralsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/growsurf_ruby/models/campaign/participant_list_referrals_params.rb

Overview

Defined Under Namespace

Modules: SortBy

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, participant_id_or_email:, desc: nil, email: nil, first_name: nil, last_name: nil, limit: nil, next_id: nil, offset: nil, referral_status: nil, sort_by: nil, request_options: {}) ⇒ Object

Parameters:

  • id (String)
  • participant_id_or_email (String)
  • desc (Boolean) (defaults to: nil)

    Return results in descending order when true.

  • email (String) (defaults to: nil)

    URL-encoded email value to filter referral results.

  • first_name (String) (defaults to: nil)

    First name value to filter results.

  • last_name (String) (defaults to: nil)

    Last name value to filter results.

  • limit (Integer) (defaults to: nil)

    Number of results to return. Maximum 100.

  • next_id (String) (defaults to: nil)

    ID to start the next paged result set with.

  • offset (Integer) (defaults to: nil)

    Offset number used to skip through a result set.

  • referral_status (Symbol, GrowsurfRuby::Models::Campaign::ReferralStatus) (defaults to: nil)
  • sort_by (Symbol, GrowsurfRuby::Models::Campaign::ParticipantListReferralsParams::SortBy) (defaults to: nil)

    Field used to sort referral results.

  • request_options (GrowsurfRuby::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/growsurf_ruby/models/campaign/participant_list_referrals_params.rb', line 74

Instance Attribute Details

#descBoolean?

Return results in descending order when true.

Returns:

  • (Boolean, nil)


25
# File 'lib/growsurf_ruby/models/campaign/participant_list_referrals_params.rb', line 25

optional :desc, GrowsurfRuby::Internal::Type::Boolean

#emailString?

URL-encoded email value to filter referral results.

Returns:

  • (String, nil)


31
# File 'lib/growsurf_ruby/models/campaign/participant_list_referrals_params.rb', line 31

optional :email, String

#first_nameString?

First name value to filter results.

Returns:

  • (String, nil)


37
# File 'lib/growsurf_ruby/models/campaign/participant_list_referrals_params.rb', line 37

optional :first_name, String

#idString

Returns:

  • (String)


14
# File 'lib/growsurf_ruby/models/campaign/participant_list_referrals_params.rb', line 14

required :id, String

#last_nameString?

Last name value to filter results.

Returns:

  • (String, nil)


43
# File 'lib/growsurf_ruby/models/campaign/participant_list_referrals_params.rb', line 43

optional :last_name, String

#limitInteger?

Number of results to return. Maximum 100.

Returns:

  • (Integer, nil)


49
# File 'lib/growsurf_ruby/models/campaign/participant_list_referrals_params.rb', line 49

optional :limit, Integer

#next_idString?

ID to start the next paged result set with.

Returns:

  • (String, nil)


55
# File 'lib/growsurf_ruby/models/campaign/participant_list_referrals_params.rb', line 55

optional :next_id, String

#offsetInteger?

Offset number used to skip through a result set.

Returns:

  • (Integer, nil)


61
# File 'lib/growsurf_ruby/models/campaign/participant_list_referrals_params.rb', line 61

optional :offset, Integer

#participant_id_or_emailString

Returns:

  • (String)


19
# File 'lib/growsurf_ruby/models/campaign/participant_list_referrals_params.rb', line 19

required :participant_id_or_email, String

#referral_statusSymbol, ...



66
# File 'lib/growsurf_ruby/models/campaign/participant_list_referrals_params.rb', line 66

optional :referral_status, enum: -> { GrowsurfRuby::Campaign::ReferralStatus }

#sort_bySymbol, ...

Field used to sort referral results.



72
# File 'lib/growsurf_ruby/models/campaign/participant_list_referrals_params.rb', line 72

optional :sort_by, enum: -> { GrowsurfRuby::Campaign::ParticipantListReferralsParams::SortBy }