Class: GrowsurfRuby::Models::Campaign::ParticipantRequestPayoutDestinationConfirmationResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- GrowsurfRuby::Models::Campaign::ParticipantRequestPayoutDestinationConfirmationResponse
- Defined in:
- lib/growsurf_ruby/models/campaign/participant_request_payout_destination_confirmation_response.rb,
sig/growsurf_ruby/models/campaign/participant_request_payout_destination_confirmation_response.rbs
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#expires_at ⇒ Integer?
When the confirmation link expires, as a Unix timestamp in milliseconds.
-
#provider ⇒ String?
The provider the participant was asked to confirm.
-
#provider_display_name ⇒ String?
The customer-facing provider name (e.g. "PayPal", "Wise").
-
#status ⇒ Symbol, ...
Confirms the message was requested.
Instance Method Summary collapse
- #initialize(expires_at: nil, provider: nil, provider_display_name: nil, status: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(expires_at: nil, provider: nil, provider_display_name: nil, status: nil) ⇒ Object
|
|
# File 'lib/growsurf_ruby/models/campaign/participant_request_payout_destination_confirmation_response.rb', line 33
|
Instance Attribute Details
#expires_at ⇒ Integer?
When the confirmation link expires, as a Unix timestamp in milliseconds.
12 |
# File 'lib/growsurf_ruby/models/campaign/participant_request_payout_destination_confirmation_response.rb', line 12 optional :expires_at, Integer, api_name: :expiresAt, nil?: true |
#provider ⇒ String?
The provider the participant was asked to confirm.
18 |
# File 'lib/growsurf_ruby/models/campaign/participant_request_payout_destination_confirmation_response.rb', line 18 optional :provider, String |
#provider_display_name ⇒ String?
The customer-facing provider name (e.g. "PayPal", "Wise").
24 |
# File 'lib/growsurf_ruby/models/campaign/participant_request_payout_destination_confirmation_response.rb', line 24 optional :provider_display_name, String, api_name: :providerDisplayName |
#status ⇒ Symbol, ...
Confirms the message was requested.
30 31 |
# File 'lib/growsurf_ruby/models/campaign/participant_request_payout_destination_confirmation_response.rb', line 30 optional :status, enum: -> { GrowsurfRuby::Campaign::ParticipantRequestPayoutDestinationConfirmationResponse::Status } |
Instance Method Details
#to_hash ⇒ {
38 |
# File 'sig/growsurf_ruby/models/campaign/participant_request_payout_destination_confirmation_response.rbs', line 38
def to_hash: -> {
|