Class: GrowsurfRuby::Models::Campaign::ParticipantRetrieveAnalyticsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb,
sig/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rbs

Overview

See Also:

  • GrowsurfRuby::Resources::Campaign::Participant#retrieve_analytics

Defined Under Namespace

Modules: Interval

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::GrowsurfRuby

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, participant_id_or_email:, days: nil, end_date: nil, include: nil, interval: nil, start_date: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see GrowsurfRuby::Models::Campaign::ParticipantRetrieveAnalyticsParams for more details.

Parameters:

  • id (String)
  • participant_id_or_email (String)
  • days (Integer) (defaults to: nil)

    Last number of days for optional series and email analytics. Defaults to 365. Maxi

  • end_date (Integer) (defaults to: nil)

    End of a custom series and email analytics window as a Unix timestamp in milli

  • include (String) (defaults to: nil)

    Comma-separated optional data. series returns this participant's own activity

  • interval (Symbol, GrowsurfRuby::Models::Campaign::ParticipantRetrieveAnalyticsParams::Interval) (defaults to: nil)

    Bucket size for the series (only used when include contains series).

  • start_date (Integer) (defaults to: nil)

    Start of a custom series and email analytics window as a Unix timestamp in mi

  • request_options (GrowsurfRuby::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 62

Instance Attribute Details

#daysInteger?

Last number of days for optional series and email analytics. Defaults to 365. Maximum 1825. Does not filter the top-level all-time totals.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


26
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 26

optional :days, Integer

#end_dateInteger?

End of a custom series and email analytics window as a Unix timestamp in milliseconds. Set it together with startDate. Does not filter the top-level all-time totals.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


34
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 34

optional :end_date, Integer

#idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 14

required :id, String

#includeString?

Comma-separated optional data. series returns this participant's own activity per period; email returns sent, delivered, opened, clicked, bounced, spamComplaints, and per-email-type metrics attributed to the participant for the requested analytics window (including invitations they sent). Request both in either order to add email counts to every series item for emails sent during that period. Only documented tokens are accepted; an unknown token returns 400.

Parameters:

  • (String)

Returns:

  • (String, nil)


45
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 45

optional :include, String

#intervalSymbol, ...

Bucket size for the series (only used when include contains series). Defaults to day.



52
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 52

optional :interval, enum: -> { GrowsurfRuby::Campaign::ParticipantRetrieveAnalyticsParams::Interval }

#participant_id_or_emailString

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 19

required :participant_id_or_email, String

#start_dateInteger?

Start of a custom series and email analytics window as a Unix timestamp in milliseconds. Set it together with endDate. Does not filter the top-level all-time totals.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


60
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 60

optional :start_date, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


57
# File 'sig/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rbs', line 57

def to_hash: -> {