Class: GrowsurfRuby::Models::Campaign::ParticipantTriggerReferralParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- GrowsurfRuby::Models::Campaign::ParticipantTriggerReferralParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/growsurf_ruby/models/campaign/participant_trigger_referral_params.rb,
sig/growsurf_ruby/models/campaign/participant_trigger_referral_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::GrowsurfRuby
Instance Attribute Summary collapse
-
#delay_in_days ⇒ Integer?
Number of whole days to hold referral credit before it is awarded.
- #id ⇒ String
- #participant_id_or_email ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, participant_id_or_email:, delay_in_days: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ParticipantTriggerReferralParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, participant_id_or_email:, delay_in_days: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see GrowsurfRuby::Models::Campaign::ParticipantTriggerReferralParams for more details.
|
|
# File 'lib/growsurf_ruby/models/campaign/participant_trigger_referral_params.rb', line 31
|
Instance Attribute Details
#delay_in_days ⇒ Integer?
Number of whole days to hold referral credit before it is awarded. Useful for honoring a refund window before crediting a referrer. Omit this field to award credit immediately. The credit is awarded automatically once the delay elapses, and can be cancelled before then with the Cancel delayed referral trigger request.
29 |
# File 'lib/growsurf_ruby/models/campaign/participant_trigger_referral_params.rb', line 29 optional :delay_in_days, Integer, api_name: :delayInDays |
#id ⇒ String
14 |
# File 'lib/growsurf_ruby/models/campaign/participant_trigger_referral_params.rb', line 14 required :id, String |
#participant_id_or_email ⇒ String
19 |
# File 'lib/growsurf_ruby/models/campaign/participant_trigger_referral_params.rb', line 19 required :participant_id_or_email, String |
Instance Method Details
#to_hash ⇒ {
27 |
# File 'sig/growsurf_ruby/models/campaign/participant_trigger_referral_params.rbs', line 27
def to_hash: -> {
|