Class: GrowsurfRuby::Models::CampaignListCommissionsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- GrowsurfRuby::Models::CampaignListCommissionsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/growsurf_ruby/models/campaign_list_commissions_params.rb,
sig/growsurf_ruby/models/campaign_list_commissions_params.rbs
Overview
Defined Under Namespace
Modules: Status
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::GrowsurfRuby
Instance Attribute Summary collapse
- #id ⇒ String
-
#limit ⇒ Integer?
Number of results to return.
-
#next_id ⇒ String?
ID to start the next paged result set with.
-
#status ⇒ Symbol, ...
Participant commission status.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(id:, limit: nil, next_id: nil, status: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, limit: nil, next_id: nil, status: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/growsurf_ruby/models/campaign_list_commissions_params.rb', line 33
|
Instance Attribute Details
#id ⇒ String
13 |
# File 'lib/growsurf_ruby/models/campaign_list_commissions_params.rb', line 13 required :id, String |
#limit ⇒ Integer?
Number of results to return. Maximum 100.
19 |
# File 'lib/growsurf_ruby/models/campaign_list_commissions_params.rb', line 19 optional :limit, Integer |
#next_id ⇒ String?
ID to start the next paged result set with.
25 |
# File 'lib/growsurf_ruby/models/campaign_list_commissions_params.rb', line 25 optional :next_id, String |
#status ⇒ Symbol, ...
Participant commission status.
31 |
# File 'lib/growsurf_ruby/models/campaign_list_commissions_params.rb', line 31 optional :status, enum: -> { GrowsurfRuby::CampaignListCommissionsParams::Status } |
Instance Method Details
#to_hash ⇒ {
40 |
# File 'sig/growsurf_ruby/models/campaign_list_commissions_params.rbs', line 40
def to_hash: -> {
|