Class: GrowsurfRuby::Models::CampaignListLeaderboardParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/growsurf_ruby/models/campaign_list_leaderboard_params.rb

Overview

Defined Under Namespace

Modules: LeaderboardType

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, is_monthly: nil, leaderboard_type: nil, limit: nil, next_id: nil, request_options: {}) ⇒ Object

Parameters:

  • id (String)
  • is_monthly (Boolean) (defaults to: nil)

    Deprecated. Use ‘leaderboardType=CURRENT_MONTH` instead.

  • leaderboard_type (Symbol, GrowsurfRuby::Models::CampaignListLeaderboardParams::LeaderboardType) (defaults to: nil)

    Leaderboard ordering mode.

  • limit (Integer) (defaults to: nil)

    Number of results to return. Maximum 100.

  • next_id (String) (defaults to: nil)

    ID to start the next paged result set with.

  • request_options (GrowsurfRuby::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/growsurf_ruby/models/campaign_list_leaderboard_params.rb', line 39

Instance Attribute Details

#idString

Returns:

  • (String)


13
# File 'lib/growsurf_ruby/models/campaign_list_leaderboard_params.rb', line 13

required :id, String

#is_monthlyBoolean?

Deprecated. Use ‘leaderboardType=CURRENT_MONTH` instead.

Returns:

  • (Boolean, nil)


19
# File 'lib/growsurf_ruby/models/campaign_list_leaderboard_params.rb', line 19

optional :is_monthly, GrowsurfRuby::Internal::Type::Boolean

#leaderboard_typeSymbol, ...

Leaderboard ordering mode.



25
# File 'lib/growsurf_ruby/models/campaign_list_leaderboard_params.rb', line 25

optional :leaderboard_type, enum: -> { GrowsurfRuby::CampaignListLeaderboardParams::LeaderboardType }

#limitInteger?

Number of results to return. Maximum 100.

Returns:

  • (Integer, nil)


31
# File 'lib/growsurf_ruby/models/campaign_list_leaderboard_params.rb', line 31

optional :limit, Integer

#next_idString?

ID to start the next paged result set with.

Returns:

  • (String, nil)


37
# File 'lib/growsurf_ruby/models/campaign_list_leaderboard_params.rb', line 37

optional :next_id, String