Class: GrowsurfRuby::Models::CampaignListReferralsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- GrowsurfRuby::Models::CampaignListReferralsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/growsurf_ruby/models/campaign_list_referrals_params.rb
Overview
Defined Under Namespace
Modules: SortBy
Instance Attribute Summary collapse
-
#desc ⇒ Boolean?
Return results in descending order when true.
-
#email ⇒ String?
URL-encoded email value to filter referral results.
-
#first_name ⇒ String?
First name value to filter results.
- #id ⇒ String
-
#last_name ⇒ String?
Last name value to filter results.
-
#limit ⇒ Integer?
Number of results to return.
-
#next_id ⇒ String?
ID to start the next paged result set with.
-
#offset ⇒ Integer?
Offset number used to skip through a result set.
- #referral_status ⇒ Symbol, ...
-
#sort_by ⇒ Symbol, ...
Field used to sort referral results.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, desc: nil, email: nil, first_name: nil, last_name: nil, limit: nil, next_id: nil, offset: nil, referral_status: nil, sort_by: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/growsurf_ruby/models/campaign_list_referrals_params.rb', line 68
|
Instance Attribute Details
#desc ⇒ Boolean?
Return results in descending order when true.
19 |
# File 'lib/growsurf_ruby/models/campaign_list_referrals_params.rb', line 19 optional :desc, GrowsurfRuby::Internal::Type::Boolean |
#email ⇒ String?
URL-encoded email value to filter referral results.
25 |
# File 'lib/growsurf_ruby/models/campaign_list_referrals_params.rb', line 25 optional :email, String |
#first_name ⇒ String?
First name value to filter results.
31 |
# File 'lib/growsurf_ruby/models/campaign_list_referrals_params.rb', line 31 optional :first_name, String |
#id ⇒ String
13 |
# File 'lib/growsurf_ruby/models/campaign_list_referrals_params.rb', line 13 required :id, String |
#last_name ⇒ String?
Last name value to filter results.
37 |
# File 'lib/growsurf_ruby/models/campaign_list_referrals_params.rb', line 37 optional :last_name, String |
#limit ⇒ Integer?
Number of results to return. Maximum 100.
43 |
# File 'lib/growsurf_ruby/models/campaign_list_referrals_params.rb', line 43 optional :limit, Integer |
#next_id ⇒ String?
ID to start the next paged result set with.
49 |
# File 'lib/growsurf_ruby/models/campaign_list_referrals_params.rb', line 49 optional :next_id, String |
#offset ⇒ Integer?
Offset number used to skip through a result set.
55 |
# File 'lib/growsurf_ruby/models/campaign_list_referrals_params.rb', line 55 optional :offset, Integer |
#referral_status ⇒ Symbol, ...
60 |
# File 'lib/growsurf_ruby/models/campaign_list_referrals_params.rb', line 60 optional :referral_status, enum: -> { GrowsurfRuby::Campaign::ReferralStatus } |
#sort_by ⇒ Symbol, ...
Field used to sort referral results.
66 |
# File 'lib/growsurf_ruby/models/campaign_list_referrals_params.rb', line 66 optional :sort_by, enum: -> { GrowsurfRuby::CampaignListReferralsParams::SortBy } |