Class: GrowsurfRuby::Models::CampaignRetrieveAnalyticsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/growsurf_ruby/models/campaign_retrieve_analytics_response.rb,
sig/growsurf_ruby/models/campaign_retrieve_analytics_response.rbs

Overview

See Also:

  • GrowsurfRuby::Resources::Campaign#retrieve_analytics

Defined Under Namespace

Classes: Analytics, PreviousPeriod, Rates, Series, StatusCounts

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(android_native_shares: nil, bluesky_shares: nil, copy_ref_link_shares: nil, email_shares: nil, facebook_shares: nil, impressions: nil, invites: nil, ios_native_shares: nil, linked_in_shares: nil, messenger_shares: nil, participants: nil, period_start: nil, pinterest_shares: nil, qrcode_shares: nil, reddit_shares: nil, referral_credit_expireds: nil, referral_credit_pendings: nil, referrals: nil, sms_shares: nil, telegram_shares: nil, threads_shares: nil, total_commission_count: nil, total_commissions: nil, total_revenue: nil, tumblr_shares: nil, twitter_shares: nil, unique_impressions: nil, wechat_shares: nil, whats_app_shares: nil) ⇒ Object

Some parameter documentations has been truncated, see Series for more details.

Parameters:

  • android_native_shares (Integer) (defaults to: nil)
  • bluesky_shares (Integer) (defaults to: nil)
  • copy_ref_link_shares (Integer) (defaults to: nil)
  • email_shares (Integer) (defaults to: nil)
  • facebook_shares (Integer) (defaults to: nil)
  • impressions (Integer) (defaults to: nil)
  • invites (Integer) (defaults to: nil)
  • ios_native_shares (Integer) (defaults to: nil)
  • linked_in_shares (Integer) (defaults to: nil)
  • messenger_shares (Integer) (defaults to: nil)
  • participants (Integer) (defaults to: nil)
  • period_start (Integer) (defaults to: nil)

    Start of the period, as a Unix timestamp in milliseconds (UTC).

  • pinterest_shares (Integer) (defaults to: nil)
  • qrcode_shares (Integer) (defaults to: nil)
  • reddit_shares (Integer) (defaults to: nil)
  • referral_credit_expireds (Integer) (defaults to: nil)
  • referral_credit_pendings (Integer) (defaults to: nil)
  • referrals (Integer) (defaults to: nil)
  • sms_shares (Integer) (defaults to: nil)
  • telegram_shares (Integer) (defaults to: nil)
  • threads_shares (Integer) (defaults to: nil)
  • total_commission_count (Integer) (defaults to: nil)

    Affiliate programs only. Number of commission records.

  • total_commissions (Integer) (defaults to: nil)

    Affiliate programs only. Commissions in the smallest unit of the program currenc

  • total_revenue (Integer) (defaults to: nil)

    Affiliate programs only. Revenue in the smallest unit of the program currency.

  • tumblr_shares (Integer) (defaults to: nil)
  • twitter_shares (Integer) (defaults to: nil)
  • unique_impressions (Integer) (defaults to: nil)
  • wechat_shares (Integer) (defaults to: nil)
  • whats_app_shares (Integer) (defaults to: nil)


# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_response.rb', line 56

Instance Attribute Details

#analyticsGrowsurfRuby::Models::CampaignRetrieveAnalyticsResponse::Analytics



10
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_response.rb', line 10

required :analytics, -> { GrowsurfRuby::Models::CampaignRetrieveAnalyticsResponse::Analytics }

#end_dateInteger

Parameters:

  • value (Integer)

Returns:

  • (Integer)


15
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_response.rb', line 15

required :end_date, Integer, api_name: :endDate

#previous_periodGrowsurfRuby::Models::CampaignRetrieveAnalyticsResponse::PreviousPeriod?

Present only when include contains previousPeriod.



26
27
28
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_response.rb', line 26

optional :previous_period,
-> { GrowsurfRuby::Models::CampaignRetrieveAnalyticsResponse::PreviousPeriod },
api_name: :previousPeriod

#ratesGrowsurfRuby::Models::CampaignRetrieveAnalyticsResponse::Rates?

Present only when include contains rates.



34
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_response.rb', line 34

optional :rates, -> { GrowsurfRuby::Models::CampaignRetrieveAnalyticsResponse::Rates }

#seriesArray<GrowsurfRuby::Models::CampaignRetrieveAnalyticsResponse::Series>?

Present only when interval is day, week, or month. Per-period totals, ascending.



41
42
43
44
45
46
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_response.rb', line 41

optional :series,
-> {
  GrowsurfRuby::Internal::Type::ArrayOf[
    GrowsurfRuby::Models::CampaignRetrieveAnalyticsResponse::Series
  ]
}

#start_dateInteger

Parameters:

  • value (Integer)

Returns:

  • (Integer)


20
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_response.rb', line 20

required :start_date, Integer, api_name: :startDate

#status_countsGrowsurfRuby::Models::CampaignRetrieveAnalyticsResponse::StatusCounts?

Present only when include contains statusCounts.



52
53
54
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_response.rb', line 52

optional :status_counts,
-> { GrowsurfRuby::Models::CampaignRetrieveAnalyticsResponse::StatusCounts },
api_name: :statusCounts

Instance Method Details

#to_hash{

Returns:

  • ({)


55
# File 'sig/growsurf_ruby/models/campaign_retrieve_analytics_response.rbs', line 55

def to_hash: -> {