Class: GrowsurfRuby::Models::ReferralFlowScreenshotsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- GrowsurfRuby::Models::ReferralFlowScreenshotsResponse
- Defined in:
- lib/growsurf_ruby/models/referral_flow_screenshots_response.rb,
sig/growsurf_ruby/models/referral_flow_screenshots_response.rbs
Overview
Defined Under Namespace
Classes: ReferralFlowScreenshot
Instance Attribute Summary collapse
-
#generated_at ⇒ Integer
When the screenshots were generated, as a Unix timestamp in milliseconds.
-
#referred_friend ⇒ GrowsurfRuby::Models::ReferralFlowScreenshotsResponse::ReferralFlowScreenshot
Screenshot of the referral flow as the referred friend sees it.
-
#referrer ⇒ GrowsurfRuby::Models::ReferralFlowScreenshotsResponse::ReferralFlowScreenshot
Screenshot of the referral flow as a signed-in referrer sees it.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
17 |
# File 'sig/growsurf_ruby/models/referral_flow_screenshots_response.rbs', line 17
def initialize: (
|
Instance Attribute Details
#generated_at ⇒ Integer
When the screenshots were generated, as a Unix timestamp in milliseconds.
25 |
# File 'lib/growsurf_ruby/models/referral_flow_screenshots_response.rb', line 25 required :generated_at, Integer, api_name: :generatedAt |
#referred_friend ⇒ GrowsurfRuby::Models::ReferralFlowScreenshotsResponse::ReferralFlowScreenshot
Screenshot of the referral flow as the referred friend sees it.
17 18 19 |
# File 'lib/growsurf_ruby/models/referral_flow_screenshots_response.rb', line 17 required :referred_friend, -> { GrowsurfRuby::Models::ReferralFlowScreenshotsResponse::ReferralFlowScreenshot }, api_name: :referredFriend |
#referrer ⇒ GrowsurfRuby::Models::ReferralFlowScreenshotsResponse::ReferralFlowScreenshot
Screenshot of the referral flow as a signed-in referrer sees it.
11 |
# File 'lib/growsurf_ruby/models/referral_flow_screenshots_response.rb', line 11 required :referrer, -> { GrowsurfRuby::Models::ReferralFlowScreenshotsResponse::ReferralFlowScreenshot } |
Instance Method Details
#to_hash ⇒ {
23 |
# File 'sig/growsurf_ruby/models/referral_flow_screenshots_response.rbs', line 23
def to_hash: -> {
|