Class: GrowsurfRuby::Models::Team
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- GrowsurfRuby::Models::Team
- Defined in:
- lib/growsurf_ruby/models/team.rb,
sig/growsurf_ruby/models/team.rbs
Overview
Defined Under Namespace
Modules: VerificationStatus
Instance Attribute Summary collapse
-
#name ⇒ String
The team's display name.
-
#verification_requested_at ⇒ Integer?
When team verification was last requested, as a Unix timestamp in milliseconds.
-
#verification_status ⇒ Symbol, GrowsurfRuby::Models::Team::VerificationStatus
GrowSurf team verification state.
Instance Method Summary collapse
- #initialize(name:, verification_status:, verification_requested_at:) ⇒ Object constructor
- #to_hash ⇒ GrowsurfRuby::Models::team
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, verification_status:, verification_requested_at:) ⇒ Object
|
|
# File 'lib/growsurf_ruby/models/team.rb', line 28
|
Instance Attribute Details
#name ⇒ String
The team's display name.
11 |
# File 'lib/growsurf_ruby/models/team.rb', line 11 required :name, String |
#verification_requested_at ⇒ Integer?
When team verification was last requested, as a Unix timestamp in milliseconds.
26 |
# File 'lib/growsurf_ruby/models/team.rb', line 26 required :verification_requested_at, Integer, api_name: :verificationRequestedAt, nil?: true |
#verification_status ⇒ Symbol, GrowsurfRuby::Models::Team::VerificationStatus
GrowSurf team verification state. VERIFIED is required before a program can
send participant emails.
18 19 20 |
# File 'lib/growsurf_ruby/models/team.rb', line 18 required :verification_status, enum: -> { GrowsurfRuby::Models::Team::VerificationStatus }, api_name: :verificationStatus |
Instance Method Details
#to_hash ⇒ GrowsurfRuby::Models::team
21 |
# File 'sig/growsurf_ruby/models/team.rbs', line 21
def to_hash: -> GrowsurfRuby::Models::team
|