Class: GrowsurfRuby::Models::Campaign::ParticipantActivityLogsResponse::ActivityLog
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- GrowsurfRuby::Models::Campaign::ParticipantActivityLogsResponse::ActivityLog
- Defined in:
- lib/growsurf_ruby/models/campaign/participant_activity_logs_response.rb,
sig/growsurf_ruby/models/campaign/participant_activity_logs_response.rbs
Instance Attribute Summary collapse
-
#created_at ⇒ Integer
When the activity occurred, as a Unix timestamp in milliseconds.
- #text ⇒ String
-
#type ⇒ String
The activity family (e.g.
REFERRAL,SHARE,REWARD,EMAIL,COMMON).
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(created_at:, text:, type:) ⇒ Object
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/growsurf_ruby/models/campaign/participant_activity_logs_response.rb', line 37 class ActivityLog < GrowsurfRuby::Internal::Type::BaseModel # @!attribute created_at # When the activity occurred, as a Unix timestamp in milliseconds. # # @return [Integer] required :created_at, Integer, api_name: :createdAt # @!attribute text # # @return [String] required :text, String # @!attribute type # The activity family (e.g. `REFERRAL`, `SHARE`, `REWARD`, `EMAIL`, `COMMON`). # # @return [String] required :type, String # @!method initialize(created_at:, text:, type:) # @param created_at [Integer] When the activity occurred, as a Unix timestamp in milliseconds. # # @param text [String] # # @param type [String] The activity family (e.g. `REFERRAL`, `SHARE`, `REWARD`, `EMAIL`, `COMMON`). end |
Instance Attribute Details
#created_at ⇒ Integer
When the activity occurred, as a Unix timestamp in milliseconds.
42 |
# File 'lib/growsurf_ruby/models/campaign/participant_activity_logs_response.rb', line 42 required :created_at, Integer, api_name: :createdAt |
#text ⇒ String
47 |
# File 'lib/growsurf_ruby/models/campaign/participant_activity_logs_response.rb', line 47 required :text, String |
#type ⇒ String
The activity family (e.g. REFERRAL, SHARE, REWARD, EMAIL, COMMON).
53 |
# File 'lib/growsurf_ruby/models/campaign/participant_activity_logs_response.rb', line 53 required :type, String |
Instance Method Details
#to_hash ⇒ {
50 |
# File 'sig/growsurf_ruby/models/campaign/participant_activity_logs_response.rbs', line 50
def to_hash: -> {
|