Class: GrowsurfRuby::Models::Campaign::ParticipantGetPayoutDestinationResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- GrowsurfRuby::Models::Campaign::ParticipantGetPayoutDestinationResponse
- Defined in:
- lib/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rb,
sig/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rbs
Overview
Defined Under Namespace
Classes: Destination
Instance Attribute Summary collapse
-
#active_provider ⇒ String?
The provider that currently gets paid, or null until the participant confirms one.
-
#destinations ⇒ Array<GrowsurfRuby::Models::Campaign::ParticipantGetPayoutDestinationResponse::Destination>?
One entry per enabled payout provider describing the participant's destination for it.
-
#enabled_providers ⇒ Array<String>?
The payout providers enabled for this program.
Instance Method Summary collapse
- #initialize(active_provider: nil, destinations: nil, enabled_providers: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(active_provider: nil, destinations: nil, enabled_providers: nil) ⇒ Object
|
|
# File 'lib/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rb', line 37
|
Instance Attribute Details
#active_provider ⇒ String?
The provider that currently gets paid, or null until the participant confirms one.
13 |
# File 'lib/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rb', line 13 optional :active_provider, String, api_name: :activeProvider, nil?: true |
#destinations ⇒ Array<GrowsurfRuby::Models::Campaign::ParticipantGetPayoutDestinationResponse::Destination>?
One entry per enabled payout provider describing the participant's destination for it.
20 21 22 23 24 25 |
# File 'lib/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rb', line 20 optional :destinations, -> { GrowsurfRuby::Internal::Type::ArrayOf[ GrowsurfRuby::Campaign::ParticipantGetPayoutDestinationResponse::Destination ] } |
#enabled_providers ⇒ Array<String>?
The payout providers enabled for this program.
31 32 33 34 35 |
# File 'lib/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rb', line 31 optional :enabled_providers, -> { GrowsurfRuby::Internal::Type::ArrayOf[String] }, api_name: :enabledProviders |
Instance Method Details
#to_hash ⇒ {
32 |
# File 'sig/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rbs', line 32
def to_hash: -> {
|