Class: GrowsurfRuby::Models::Campaign::ParticipantGetPayoutDestinationResponse::Destination
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- GrowsurfRuby::Models::Campaign::ParticipantGetPayoutDestinationResponse::Destination
- Defined in:
- lib/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rb,
sig/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rbs
Overview
Defined Under Namespace
Modules: LegalEntityType
Instance Attribute Summary collapse
-
#claim_email ⇒ String?
The confirmed payout email for this provider.
-
#confirmed_at ⇒ Integer?
When the destination was confirmed, as a Unix timestamp in milliseconds.
-
#legal_entity_type ⇒ Symbol, ...
The legal recipient type the participant confirmed, if any.
-
#needs_repair_reason ⇒ String?
When status is
NEEDS_REPAIR, why (e.g. a bounced delivery). -
#provider ⇒ String?
The payout provider this entry describes.
-
#provider_display_name ⇒ String?
The customer-facing provider name (e.g. "PayPal", "Wise").
-
#status ⇒ String?
The destination's current status:
NONE(not set up),PENDING_CONFIRMATION,CONFIRMED,ACTIVE,NEEDS_REPAIR, orEXPIRED.
Instance Method Summary collapse
- #initialize(claim_email: nil, confirmed_at: nil, legal_entity_type: nil, needs_repair_reason: nil, provider: nil, provider_display_name: nil, status: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(claim_email: nil, confirmed_at: nil, legal_entity_type: nil, needs_repair_reason: nil, provider: nil, provider_display_name: nil, status: nil) ⇒ Object
|
|
# File 'lib/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rb', line 95
|
Instance Attribute Details
#claim_email ⇒ String?
The confirmed payout email for this provider.
50 |
# File 'lib/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rb', line 50 optional :claim_email, String, api_name: :claimEmail, nil?: true |
#confirmed_at ⇒ Integer?
When the destination was confirmed, as a Unix timestamp in milliseconds.
56 |
# File 'lib/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rb', line 56 optional :confirmed_at, Integer, api_name: :confirmedAt, nil?: true |
#legal_entity_type ⇒ Symbol, ...
The legal recipient type the participant confirmed, if any.
62 63 64 65 66 67 |
# File 'lib/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rb', line 62 optional :legal_entity_type, enum: -> { GrowsurfRuby::Campaign::ParticipantGetPayoutDestinationResponse::Destination::LegalEntityType }, api_name: :legalEntityType, nil?: true |
#needs_repair_reason ⇒ String?
When status is NEEDS_REPAIR, why (e.g. a bounced delivery).
73 |
# File 'lib/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rb', line 73 optional :needs_repair_reason, String, api_name: :needsRepairReason, nil?: true |
#provider ⇒ String?
The payout provider this entry describes.
79 |
# File 'lib/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rb', line 79 optional :provider, String |
#provider_display_name ⇒ String?
The customer-facing provider name (e.g. "PayPal", "Wise").
85 |
# File 'lib/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rb', line 85 optional :provider_display_name, String, api_name: :providerDisplayName |
#status ⇒ String?
The destination's current status: NONE (not set up), PENDING_CONFIRMATION,
CONFIRMED, ACTIVE, NEEDS_REPAIR, or EXPIRED. Historical superseded
or revoked destinations are projected as NONE.
93 |
# File 'lib/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rb', line 93 optional :status, String |
Instance Method Details
#to_hash ⇒ {
82 |
# File 'sig/growsurf_ruby/models/campaign/participant_get_payout_destination_response.rbs', line 82
def to_hash: -> {
|