Class: GrowsurfRuby::Models::Campaign::ParticipantRetrieveAnalyticsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- GrowsurfRuby::Models::Campaign::ParticipantRetrieveAnalyticsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb,
sig/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rbs
Overview
Defined Under Namespace
Modules: Interval
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::GrowsurfRuby
Instance Attribute Summary collapse
-
#days ⇒ Integer?
Last number of days for optional
seriesandemailanalytics. -
#end_date ⇒ Integer?
End of a custom
seriesandemailanalytics window as a Unix timestamp in milliseconds. - #id ⇒ String
-
#include ⇒ String?
Comma-separated optional data.
-
#interval ⇒ Symbol, ...
Bucket size for the
series(only used whenincludecontainsseries). - #participant_id_or_email ⇒ String
-
#start_date ⇒ Integer?
Start of a custom
seriesandemailanalytics window as a Unix timestamp in milliseconds.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, participant_id_or_email:, days: nil, end_date: nil, include: nil, interval: nil, start_date: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ParticipantRetrieveAnalyticsParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, participant_id_or_email:, days: nil, end_date: nil, include: nil, interval: nil, start_date: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see GrowsurfRuby::Models::Campaign::ParticipantRetrieveAnalyticsParams for more details.
|
|
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 62
|
Instance Attribute Details
#days ⇒ Integer?
Last number of days for optional series and email analytics. Defaults to
365. Maximum 1825. Does not filter the top-level all-time totals.
26 |
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 26 optional :days, Integer |
#end_date ⇒ Integer?
End of a custom series and email analytics window as a Unix timestamp in
milliseconds. Set it together with startDate. Does not filter the top-level
all-time totals.
34 |
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 34 optional :end_date, Integer |
#id ⇒ String
14 |
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 14 required :id, String |
#include ⇒ String?
Comma-separated optional data. series returns this participant's own activity
per period; email returns sent, delivered, opened, clicked, bounced,
spamComplaints, and per-email-type metrics attributed to the participant for
the requested analytics window (including invitations they sent). Request both
in either order to add email counts to every series item for emails sent during
that period. Only documented tokens are accepted; an unknown token returns 400.
45 |
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 45 optional :include, String |
#interval ⇒ Symbol, ...
Bucket size for the series (only used when include contains series).
Defaults to day.
52 |
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 52 optional :interval, enum: -> { GrowsurfRuby::Campaign::ParticipantRetrieveAnalyticsParams::Interval } |
#participant_id_or_email ⇒ String
19 |
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 19 required :participant_id_or_email, String |
#start_date ⇒ Integer?
Start of a custom series and email analytics window as a Unix timestamp in
milliseconds. Set it together with endDate. Does not filter the top-level
all-time totals.
60 |
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 60 optional :start_date, Integer |
Instance Method Details
#to_hash ⇒ {
57 |
# File 'sig/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rbs', line 57
def to_hash: -> {
|