Class: GrowsurfRuby::Models::Campaign::ParticipantRetrieveAnalyticsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb,
sig/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rbs

Overview

See Also:

  • GrowsurfRuby::Resources::Campaign::Participant#retrieve_analytics

Defined Under Namespace

Modules: Include, Interval

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::GrowsurfRuby

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, participant_id_or_email:, days: nil, end_date: nil, include: nil, interval: nil, start_date: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see GrowsurfRuby::Models::Campaign::ParticipantRetrieveAnalyticsParams for more details.

Parameters:



# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 53

Instance Attribute Details

#daysInteger?

Last number of days to retrieve analytics for. Defaults to 365. Maximum 1825.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


25
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 25

optional :days, Integer

#end_dateInteger?

End date of the analytics timeframe as a Unix timestamp in milliseconds. Required if days is not set.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


32
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 32

optional :end_date, Integer

#idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 14

required :id, String

#includeSymbol, ...

Set to series to also return this participant's own activity per period.



38
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 38

optional :include, enum: -> { GrowsurfRuby::Campaign::ParticipantRetrieveAnalyticsParams::Include }

#intervalSymbol, ...

Bucket size for the series (only used with include=series). Defaults to day.



44
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 44

optional :interval, enum: -> { GrowsurfRuby::Campaign::ParticipantRetrieveAnalyticsParams::Interval }

#participant_id_or_emailString

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 19

required :participant_id_or_email, String

#start_dateInteger?

Start date of the analytics timeframe as a Unix timestamp in milliseconds. Required if days is not set.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


51
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 51

optional :start_date, Integer

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 80

Instance Method Details

#to_hash{

Returns:

  • ({)


57
# File 'sig/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rbs', line 57

def to_hash: -> {