Class: GrowsurfRuby::Models::Campaign::ParticipantRetrieveAnalyticsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- GrowsurfRuby::Models::Campaign::ParticipantRetrieveAnalyticsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb,
sig/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rbs
Overview
Defined Under Namespace
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::GrowsurfRuby
Instance Attribute Summary collapse
-
#days ⇒ Integer?
Last number of days to retrieve analytics for.
-
#end_date ⇒ Integer?
End date of the analytics timeframe as a Unix timestamp in milliseconds.
- #id ⇒ String
-
#include ⇒ Symbol, ...
Set to
seriesto also return this participant's own activity per period. -
#interval ⇒ Symbol, ...
Bucket size for the
series(only used withinclude=series). - #participant_id_or_email ⇒ String
-
#start_date ⇒ Integer?
Start date of the analytics timeframe as a Unix timestamp in milliseconds.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, participant_id_or_email:, days: nil, end_date: nil, include: nil, interval: nil, start_date: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ParticipantRetrieveAnalyticsParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, participant_id_or_email:, days: nil, end_date: nil, include: nil, interval: nil, start_date: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see GrowsurfRuby::Models::Campaign::ParticipantRetrieveAnalyticsParams for more details.
|
|
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 53
|
Instance Attribute Details
#days ⇒ Integer?
Last number of days to retrieve analytics for. Defaults to 365. Maximum 1825.
25 |
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 25 optional :days, Integer |
#end_date ⇒ Integer?
End date of the analytics timeframe as a Unix timestamp in milliseconds.
Required if days is not set.
32 |
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 32 optional :end_date, Integer |
#id ⇒ String
14 |
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 14 required :id, String |
#include ⇒ Symbol, ...
Set to series to also return this participant's own activity per period.
38 |
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 38 optional :include, enum: -> { GrowsurfRuby::Campaign::ParticipantRetrieveAnalyticsParams::Include } |
#interval ⇒ Symbol, ...
Bucket size for the series (only used with include=series). Defaults to day.
44 |
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 44 optional :interval, enum: -> { GrowsurfRuby::Campaign::ParticipantRetrieveAnalyticsParams::Interval } |
#participant_id_or_email ⇒ String
19 |
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 19 required :participant_id_or_email, String |
#start_date ⇒ Integer?
Start date of the analytics timeframe as a Unix timestamp in milliseconds.
Required if days is not set.
51 |
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 51 optional :start_date, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rb', line 80
|
Instance Method Details
#to_hash ⇒ {
57 |
# File 'sig/growsurf_ruby/models/campaign/participant_retrieve_analytics_params.rbs', line 57
def to_hash: -> {
|