Class: GrowsurfRuby::Models::Campaign::Webhook
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- GrowsurfRuby::Models::Campaign::Webhook
- Defined in:
- lib/growsurf_ruby/models/campaign/webhook.rb,
sig/growsurf_ruby/models/campaign/webhook.rbs
Overview
Instance Attribute Summary collapse
-
#auto_disabled_due_to_failures ⇒ Boolean
Read-only.
- #events ⇒ Array<Symbol, GrowsurfRuby::Models::Campaign::WebhookEvent>
-
#failure_count ⇒ Integer
Read-only.
-
#id ⇒ String
The webhook id (
primaryfor the program's primary webhook). - #is_enabled ⇒ Boolean
-
#last_failure_at ⇒ Integer?
Read-only.
-
#payload_url ⇒ String?
The URL that receives webhook deliveries.
Instance Method Summary collapse
-
#initialize(auto_disabled_due_to_failures:, events:, failure_count:, id:, is_enabled:, last_failure_at: nil, payload_url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Webhook for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(auto_disabled_due_to_failures:, events:, failure_count:, id:, is_enabled:, last_failure_at: nil, payload_url: nil) ⇒ Object
Some parameter documentations has been truncated, see GrowsurfRuby::Models::Campaign::Webhook for more details.
|
|
# File 'lib/growsurf_ruby/models/campaign/webhook.rb', line 52
|
Instance Attribute Details
#auto_disabled_due_to_failures ⇒ Boolean
Read-only. Whether GrowSurf auto-disabled this webhook after repeated delivery failures.
13 14 15 |
# File 'lib/growsurf_ruby/models/campaign/webhook.rb', line 13 required :auto_disabled_due_to_failures, GrowsurfRuby::Internal::Type::Boolean, api_name: :autoDisabledDueToFailures |
#events ⇒ Array<Symbol, GrowsurfRuby::Models::Campaign::WebhookEvent>
20 |
# File 'lib/growsurf_ruby/models/campaign/webhook.rb', line 20 required :events, -> { GrowsurfRuby::Internal::Type::ArrayOf[enum: GrowsurfRuby::Campaign::WebhookEvent] } |
#failure_count ⇒ Integer
Read-only. Consecutive delivery failures.
26 |
# File 'lib/growsurf_ruby/models/campaign/webhook.rb', line 26 required :failure_count, Integer, api_name: :failureCount |
#id ⇒ String
The webhook id (primary for the program's primary webhook).
32 |
# File 'lib/growsurf_ruby/models/campaign/webhook.rb', line 32 required :id, String |
#is_enabled ⇒ Boolean
37 |
# File 'lib/growsurf_ruby/models/campaign/webhook.rb', line 37 required :is_enabled, GrowsurfRuby::Internal::Type::Boolean, api_name: :isEnabled |
#last_failure_at ⇒ Integer?
Read-only. When the last delivery failure occurred, as a Unix timestamp in milliseconds.
44 |
# File 'lib/growsurf_ruby/models/campaign/webhook.rb', line 44 optional :last_failure_at, Integer, api_name: :lastFailureAt, nil?: true |
#payload_url ⇒ String?
The URL that receives webhook deliveries.
50 |
# File 'lib/growsurf_ruby/models/campaign/webhook.rb', line 50 optional :payload_url, String, api_name: :payloadUrl, nil?: true |
Instance Method Details
#to_hash ⇒ {
40 |
# File 'sig/growsurf_ruby/models/campaign/webhook.rbs', line 40
def to_hash: -> {
|