Class: GrowsurfRuby::Models::CampaignRetrieveAnalyticsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- GrowsurfRuby::Models::CampaignRetrieveAnalyticsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/growsurf_ruby/models/campaign_retrieve_analytics_params.rb,
sig/growsurf_ruby/models/campaign_retrieve_analytics_params.rbs
Overview
Defined Under Namespace
Modules: Interval
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::GrowsurfRuby
Instance Attribute Summary collapse
-
#days ⇒ Integer?
Last number of days to retrieve analytics for.
-
#end_date ⇒ Integer?
End date of the analytics timeframe as a Unix timestamp in milliseconds.
- #id ⇒ String
-
#include ⇒ String?
Comma-separated list of optional data to include:
previousPeriodadds totals for the equal-length window immediately before the requested one;statusCountsadds reward (and, for affiliate programs, affiliate/commission/payout) status breakdowns;ratesadds derived referral rates;emailaddssent,delivered,opened,clicked,bounced,spamComplaints, and per-email-type metrics. -
#interval ⇒ Symbol, ...
When set to
day,week, ormonth, the response also includes aseriesarray with per-period totals. -
#start_date ⇒ Integer?
Start date of the analytics timeframe as a Unix timestamp in milliseconds.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, days: nil, end_date: nil, include: nil, interval: nil, start_date: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CampaignRetrieveAnalyticsParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, days: nil, end_date: nil, include: nil, interval: nil, start_date: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see GrowsurfRuby::Models::CampaignRetrieveAnalyticsParams for more details.
|
|
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_params.rb', line 55
|
Instance Attribute Details
#days ⇒ Integer?
Last number of days to retrieve analytics for. Defaults to 365. Maximum 1825.
19 |
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_params.rb', line 19 optional :days, Integer |
#end_date ⇒ Integer?
End date of the analytics timeframe as a Unix timestamp in milliseconds.
Required if days is not set.
26 |
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_params.rb', line 26 optional :end_date, Integer |
#id ⇒ String
13 |
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_params.rb', line 13 required :id, String |
#include ⇒ String?
Comma-separated list of optional data to include: previousPeriod adds totals for
the equal-length window immediately before the requested one; statusCounts adds
reward (and, for affiliate programs, affiliate/commission/payout) status breakdowns;
rates adds derived referral rates; email adds sent, delivered, opened,
clicked, bounced, spamComplaints, and per-email-type metrics. When email and
an interval are both requested, each series item also contains counts for emails
sent during that period. Combine email with previousPeriod to include the same
email metrics in both windows.
39 |
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_params.rb', line 39 optional :include, String |
#interval ⇒ Symbol, ...
When set to day, week, or month, the response also includes a series array
with per-period totals. Defaults to total (no series).
46 |
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_params.rb', line 46 optional :interval, enum: -> { GrowsurfRuby::CampaignRetrieveAnalyticsParams::Interval } |
#start_date ⇒ Integer?
Start date of the analytics timeframe as a Unix timestamp in milliseconds.
Required if days is not set.
53 |
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_params.rb', line 53 optional :start_date, Integer |
Instance Method Details
#to_hash ⇒ {
52 |
# File 'sig/growsurf_ruby/models/campaign_retrieve_analytics_params.rbs', line 52
def to_hash: -> {
|