Class: GrowsurfRuby::Models::CampaignRetrieveAnalyticsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/growsurf_ruby/models/campaign_retrieve_analytics_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, days: nil, end_date: nil, start_date: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see GrowsurfRuby::Models::CampaignRetrieveAnalyticsParams for more details.

Parameters:

  • id (String)
  • days (Integer) (defaults to: nil)

    Last number of days to retrieve analytics for. Defaults to 365. Maximum 1825.

  • end_date (Integer) (defaults to: nil)

    End date of the analytics timeframe as a Unix timestamp in milliseconds. Require

  • start_date (Integer) (defaults to: nil)

    Start date of the analytics timeframe as a Unix timestamp in milliseconds. Requi

  • request_options (GrowsurfRuby::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_params.rb', line 35

Instance Attribute Details

#daysInteger?

Last number of days to retrieve analytics for. Defaults to 365. Maximum 1825.

Returns:

  • (Integer, nil)


19
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_params.rb', line 19

optional :days, Integer

#end_dateInteger?

End date of the analytics timeframe as a Unix timestamp in milliseconds. Required if ‘days` is not set.

Returns:

  • (Integer, nil)


26
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_params.rb', line 26

optional :end_date, Integer

#idString

Returns:

  • (String)


13
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_params.rb', line 13

required :id, String

#start_dateInteger?

Start date of the analytics timeframe as a Unix timestamp in milliseconds. Required if ‘days` is not set.

Returns:

  • (Integer, nil)


33
# File 'lib/growsurf_ruby/models/campaign_retrieve_analytics_params.rb', line 33

optional :start_date, Integer