Class: GrowsurfRuby::Resources::Campaign::Options
- Inherits:
-
Object
- Object
- GrowsurfRuby::Resources::Campaign::Options
- Defined in:
- lib/growsurf_ruby/resources/campaign/options.rb,
sig/growsurf_ruby/resources/campaign/options.rbs
Instance Method Summary collapse
-
#initialize(client:) ⇒ Options
constructor
private
A new instance of Options.
-
#retrieve(id, request_options: {}) ⇒ Hash{Symbol=>Object}
Retrieves a program's options configuration — the same surface as the dashboard Program Editor's Options tab (fraud/reCAPTCHA, tax documentation, notification emails, and other program settings).
-
#update(id, body, request_options: {}) ⇒ Hash{Symbol=>Object}
Updates a program's options configuration.
Constructor Details
#initialize(client:) ⇒ Options
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Options.
57 58 59 |
# File 'lib/growsurf_ruby/resources/campaign/options.rb', line 57 def initialize(client:) @client = client end |
Instance Method Details
#retrieve(id, request_options: {}) ⇒ Hash{Symbol=>Object}
Retrieves a program's options configuration — the same surface as the dashboard Program Editor's Options tab (fraud/reCAPTCHA, tax documentation, notification emails, and other program settings).
This is a large, nested object. See the API reference for the full field list.
20 21 22 23 24 25 26 27 |
# File 'lib/growsurf_ruby/resources/campaign/options.rb', line 20 def retrieve(id, params = {}) @client.request( method: :get, path: ["campaign/%1$s/options", id], model: GrowsurfRuby::Internal::Type::HashOf[GrowsurfRuby::Internal::Type::Unknown], options: params[:request_options] ) end |
#update(id, body, request_options: {}) ⇒ Hash{Symbol=>Object}
Updates a program's options configuration. Only the fields you send are changed.
Unknown fields and invalid values return a 400.
The request body is a partial CampaignOptions object — see the API reference for the full field list.
44 45 46 47 48 49 50 51 52 |
# File 'lib/growsurf_ruby/resources/campaign/options.rb', line 44 def update(id, body, params = {}) @client.request( method: :patch, path: ["campaign/%1$s/options", id], body: body, model: GrowsurfRuby::Internal::Type::HashOf[GrowsurfRuby::Internal::Type::Unknown], options: params[:request_options] ) end |